#!/usr/bin/perl

# Add Admin
# Copyright (c) 2002-2003 Josef Zlomek
#
# This file is part of Fast File Search (FFS).
#
# FFS is free software; you can redistribute it and/or modify it
# under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2, or (at your option)
# any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA,
# or download it from http://www.gnu.org/licenses/gpl.html

use strict;
use DBI;
use Getopt::Long;

# include the common package
$_ = $0;
$_ =~ s/[^\/]*$/common.pl/;
require;

my ($help, $private);
Getopt::Long::Configure ("bundling", "no_ignore_case");
GetOptions ('help|h' => \$help,
		'common|master|c' => sub { $private = 0 },
		'private|slave|p' => \$private,
		);
if ($help || @ARGV == 0)
{
	&help ();
	exit 0;
}

my %c;
my $db;

&read_config (\%c);
if ($private)
{
	&db_connect (\%c, undef, \$db);
}
else
{
	&db_connect (\%c, \$db);
}
exit 1 if (!$db);

$SIG{INT}  = \&sig_handler;
$SIG{QUIT} = \&sig_handler;
$SIG{TERM} = \&sig_handler;

foreach my $login (@ARGV)
{
	my $AID = $db->selectrow_array ("SELECT AID FROM admin WHERE Login=" . $db->quote ($login));
	if ($AID)
	{
		print ("Admin $login already exists!\n");
	}
	else
	{
		print ("Adding admin $login\n");
		my ($password1, $password2, $name, $www, $email, $rights, $answer);

		&echo_off ();
		do {
			$password1 = &ask ("Enter password: ", "");
			print "\n";
			$password2 = &ask ("Reenter password: ", "");
			print "\n";
			print "Passwords do not match!\n" if ($password1 ne $password2);
		} while ($password1 ne $password2);
		&echo_on ();

		$name = &ask ("Enter real name: ", "");
		$www = &ask ("Enter admin's WWW page URL (including 'http://'): ", "");
		$email = &ask ("Enter e-mail: ", "");

		$rights = 0;
		while (($answer = &ask ("Does the admin have all rights [y/N]? ", "n")) !~ /^[YyNn]$/) {}
		if ($answer =~ /^[Yy]$/)
		{
			$rights = 0xffffffff;
		}
		else
		{
			while (($answer = &ask ("Is admin allowed to add FTP host [Y/n]? ", "y")) !~ /^[YyNn]$/) {}
			if ($answer =~ /^[Yy]$/)
			{
				$rights |= $c{RIGHT_FTP_ADD};
			}
			while (($answer = &ask ("Is admin allowed to edit FTP list [Y/n]? ", "y")) !~ /^[YyNn]$/) {}
			if ($answer =~ /^[Yy]$/)
			{
				$rights |= $c{RIGHT_FTP_EDIT};
				while (($answer = &ask ("Is admin allowed to purge FTP server from list [y/N]? ", "n")) !~ /^[YyNn]$/) {}
				if ($answer =~ /^[Yy]$/)
				{
					$rights |= $c{RIGHT_FTP_PURGE};
				}
			}
			while (($answer = &ask ("Is admin allowed to add SMB host [Y/n]? ", "y")) !~ /^[YyNn]$/) {}
			if ($answer =~ /^[Yy]$/)
			{
				$rights |= $c{RIGHT_SMB_ADD};
			}
			while (($answer = &ask ("Is admin allowed to edit SMB list [Y/n]? ", "y")) !~ /^[YyNn]$/) {}
			if ($answer =~ /^[Yy]$/)
			{
				$rights |= $c{RIGHT_SMB_EDIT};
				while (($answer = &ask ("Is admin allowed to purge SMB server from list [y/N]? ", "n")) !~ /^[YyNn]$/) {}
				if ($answer =~ /^[Yy]$/)
				{
					$rights |= $c{RIGHT_SMB_PURGE};
				}
			}
			while (($answer = &ask ("Is admin allowed to delete comments [Y/n]? ", "y")) !~ /^[YyNn]$/) {}
			if ($answer =~ /^[Yy]$/)
			{
				$rights |= $c{RIGHT_COMMENTS};
			}
		}

		$db->do ("INSERT INTO admin (Login,PassWord,Name,WWW,Email,Rights) VALUES (" . $db->quote ($login) . ",MD5(" . $db->quote ($login . "-" . $password1) . ")," . $db->quote ($name) . "," . $db->quote ($www) . ',' . $db->quote ($email) . ",$rights)");
	}
}
&db_disconnect ($db);

sub sig_handler
{
	&echo_on ();
	print "\n";
	&db_disconnect ($db);
	exit 0;
}

sub help
{
	print "Fast File Search adminadd.pl - Add administrator(s)\n";
	print "Usage: adminadd.pl [OPTION]... LOGIN...\n\n";
	print "    -c, --common, --master   Use common (master) database (default)\n";
	print "    -p, --private, --slave   Use private (slave) database\n";
	print "    -h, --help               Display this help and exit\n\n";
}
