#!/usr/bin/perl

# Delete Admin
# Copyright (c) 2002-2003 Josef Zlomek
#
# This file is part of Fast File Search (FFS).
#
# FFS is free software; you can redistribute it and/or modify it
# under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2, or (at your option)
# any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA,
# or download it from http://www.gnu.org/licenses/gpl.html

use strict;
use DBI;
use Getopt::Long;

# include the common package
$_ = $0;
$_ =~ s/[^\/]*$/common.pl/;
require;

my ($help, $private);
Getopt::Long::Configure ("bundling", "no_ignore_case");
GetOptions ('help|h' => \$help,
		'common|master|c' => sub { $private = 0 },
		'private|slave|p' => \$private,
		);
if ($help || @ARGV == 0)
{
	&help ();
	exit 0;
}

my %c;
my $db;

&read_config (\%c);
if ($private)
{
	&db_connect (\%c, undef, \$db);
}
else
{
	&db_connect (\%c, \$db);
}
exit 1 if (!$db);

foreach my $login (@ARGV)
{
	my $AID = $db->selectrow_array ("SELECT AID FROM admin WHERE Login=" . $db->quote ($login));
	if ($AID)
	{
		my $answer;
		while (($answer = &ask ("Do you really want to delete $login [y/n]? ", "")) !~ /^[YyNn]$/) {}
		if ($answer =~ /^[Yy]$/)
		{
			$db->do ("DELETE FROM admin WHERE AID=$AID");
		}
	}
	else
	{
		print ("Admin $login doe not exist!\n");
	}
}
&db_disconnect ($db);

sub help
{
	print "Fast File Search admindel.pl - Delete administrator(s)\n";
	print "Usage: admindel.pl [OPTION]... LOGIN...\n\n";
	print "    -c, --common, --master   Use common (master) database (default)\n";
	print "    -p, --private, --slave   Use private (slave) database\n";
	print "    -h, --help               Display this help and exit\n\n";
}
