#!/usr/bin/perl

# Export host list
# Copyright (c) 2002-2003 Josef Zlomek
#
# This file is part of Fast File Search (FFS).
#
# FFS is free software; you can redistribute it and/or modify it
# under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2, or (at your option)
# any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA,
# or download it from http://www.gnu.org/licenses/gpl.html

use strict;
use DBI;
use Getopt::Long;

# include the common package
$_ = $0;
$_ =~ s/[^\/]*$/common.pl/;
require;

my ($help, $private);
Getopt::Long::Configure ("bundling", "no_ignore_case");
GetOptions ('help|h' => \$help,
		'common|master|c' => sub { $private = 0 },
		'private|slave|p' => \$private,
		);
if ($help)
{
	&help ();
	exit 0;
}

my %c;
my ($db, $res);

&read_config (\%c);
if ($private)
{
	&db_connect (\%c, undef, \$db);
}
else
{
	&db_connect (\%c, \$db);
}
exit 1 if (!$db);

$res = $db->selectall_arrayref ("SELECT host.HID,Period,ScanOrder,Flags,HostName,Login,PassWord,Port,EditableBy,Comment,StartingDir,IP,FileList FROM ftp LEFT JOIN host USING (HID)");
$res = $db->selectall_arrayref ("SELECT host.HID,Period,ScanOrder,Flags,HostName,Login,PassWord,Port,EditableBy,Comment,StartingDir,IP FROM ftp LEFT JOIN host USING (HID)") if (!defined ($res));
$res = $db->selectall_arrayref ("SELECT host.HID,Period,ScanOrder,Flags,HostName,Login,PassWord,Port,EditableBy,Comment,StartingDir FROM ftp LEFT JOIN host USING (HID)") if (!defined ($res));
$res = $db->selectall_arrayref ("SELECT host.HID,Period,ScanOrder,Flags,HostName,Login,PassWord,Port,EditableBy,Comment FROM ftp LEFT JOIN host USING (HID)") if (!defined ($res));
foreach (@$res)
{
	print $_->[0], ',', $_->[1], ',', $_->[2], ',', $_->[3] & ($c{HOST_DELETE} | $c{HOST_PURGE} | $c{HOST_PASSIVE_MODE} | $c{HOST_LS_RECURSIVE}), ',', &quote ($_->[4]), ',', &quote ($_->[5]), ',', &quote ($_->[6]), ',', $_->[7], ',', &quote ($_->[8]), ',', &quote ($_->[9]), ',', &quote ($_->[10]), ',', &quote ($_->[11]), ',', &quote ($_->[12]), "\n";
}

print "\n";

$res = $db->selectall_arrayref ("SELECT host.HID,Period,ScanOrder,Flags,HostName,WorkGroup,IP FROM smb LEFT JOIN host USING (HID)");
foreach (@$res)
{
	print $_->[0], ',', $_->[1], ',', $_->[2], ',', $_->[3] & ($c{HOST_DELETE} | $c{HOST_PURGE} | $c{HOST_MANUAL_CHANGES}), ',', &quote ($_->[4]), ',', &quote ($_->[5]), ',', &quote ($_->[6]), "\n";
}

&db_disconnect ($db);

sub help
{
	print "Fast File Search export_host_list.pl -  Export host list\n";
	print "Usage: export_host_list.pl [OPTION]...\n\n";
	print "    -c, --common, --master   Use common (master) database (default)\n";
	print "    -p, --private, --slave   Use private (slave) database\n";
	print "    -h, --help               Display this help and exit\n\n";
}
