#!/usr/bin/perl

# Import admins
# Copyright (c) 2002-2003 Josef Zlomek
#
# This file is part of Fast File Search (FFS).
#
# FFS is free software; you can redistribute it and/or modify it
# under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2, or (at your option)
# any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA,
# or download it from http://www.gnu.org/licenses/gpl.html

use strict;
use DBI;
use Getopt::Long;

# include the common package
$_ = $0;
$_ =~ s/[^\/]*$/common.pl/;
require;
use vars qw($import_num $import_str0 $import_str1);

my ($help, $private, $overwrite);
Getopt::Long::Configure ("bundling", "no_ignore_case");
GetOptions ('help|h' => \$help,
		'merge|m' => sub { $overwrite = 0 },
		'overwrite|o' => \$overwrite,
		'common|master|c' => sub { $private = 0 },
		'private|slave|p' => \$private,
		);
if ($help)
{
	&help ();
	exit 0;
}

my %c;
my $db;

&read_config (\%c);
if ($private)
{
	&db_connect (\%c, undef, \$db);
}
else
{
	&db_connect (\%c, \$db);
}
exit 1 if (!$db);

while (<>)
{
	chomp;
	last if (/^\r?$/);
	if (/^$import_num,$import_str1,'([0-9a-fA-F]{32})',$import_str0,$import_str0,$import_num,$import_str0$/)
	{
		my $AID = $1;
		my $login = &unquote ($2);
		my $password = &unquote ($3);
		my $name = &unquote ($4);
		my $email = &unquote ($5);
		my $rights = $6;
		my $www = &unquote ($7);

		$db->do ("LOCK TABLES admin WRITE");
		if ($overwrite)
		{
			$db->do ("REPLACE INTO admin (AID,Login,PassWord,Name,WWW,Email,Rights) VALUES ($AID," . $db->quote ($login) . "," . $db->quote ($password) . "," . $db->quote ($name) . "," . $db->quote ($www) . "," . $db->quote ($email) . ",$rights)");
			$db->do ("DELETE FROM admin WHERE AID!=$AID AND Login=" . $db->quote ($login));
		}
		else
		{
			$AID = $db->selectrow_array ("SELECT AID FROM admin WHERE Login=" . $db->quote ($login));
			if ($AID)
			{
				$db->do ("UPDATE admin SET Login=" . $db->quote ($login) . ",PassWord=" . $db->quote ($password) . ",Name=" . $db->quote ($name) . ",WWW=" . $db->quote ($www) . ",Email=" . $db->quote ($email) . ",Rights=$rights,LoginTime=0,LoginIP='' WHERE AID=$AID");
			}
			else
			{
				$db->do ("INSERT INTO admin (Login,PassWord,Name,WWW,Email,Rights) VALUES (" . $db->quote ($login) . "," . $db->quote ($password) . "," . $db->quote ($name) . "," . $db->quote ($www) . "," . $db->quote ($email) . ",$rights)");
			}
		}
		$db->do ("UNLOCK TABLES");
	}
}

&db_disconnect ($db);

sub help
{
	print "Fast File Search import_admins.pl - Import admins\n";
	print "Usage: import_admins.pl [OPTION]... [FILE]...\n\n";
	print "    -m, --merge              Merge the database with FILEs (default)\n";
	print "    -o, --overwrite          Overwrite the records with the same ID\n";
	print "    -c, --common, --master   Use common (master) database (default)\n";
	print "    -p, --private, --slave   Use private (slave) database\n";
	print "    -h, --help               Display this help and exit\n\n";
}
