#!/usr/bin/perl

# Import comments
# Copyright (c) 2002-2003 Josef Zlomek
#
# This file is part of Fast File Search (FFS).
#
# FFS is free software; you can redistribute it and/or modify it
# under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2, or (at your option)
# any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA,
# or download it from http://www.gnu.org/licenses/gpl.html

use strict;
use DBI;
use Getopt::Long;

# include the common package
$_ = $0;
$_ =~ s/[^\/]*$/common.pl/;
require;
use vars qw($import_num $import_str0 $import_str1);

my ($help, $private, $overwrite);
Getopt::Long::Configure ("bundling", "no_ignore_case");
GetOptions ('help|h' => \$help,
		'merge|m' => sub { $overwrite = 0 },
		'overwrite|o' => \$overwrite,
		'common|master|c' => sub { $private = 0 },
		'private|slave|p' => \$private,
		);
if ($help)
{
	&help ();
	exit 0;
}

my %c;
my $db;

&read_config (\%c);
if ($private)
{
	&db_connect (\%c, undef, \$db);
}
else
{
	&db_connect (\%c, \$db);
}
exit 1 if (!$db);

while (<>)
{
	chomp;
	last if (/^\r?$/);
	if (/^$import_num,$import_num,$import_str0,$import_str0,$import_str1$/)
	{
		my $CID = $1;
		my $time = $2;
		my $name = &unquote ($3);
		my $email = &unquote ($4);
		my $comment = &unquote ($5);

		$db->do ("LOCK TABLES comments WRITE");
		if ($overwrite)
		{
			$db->do ("REPLACE INTO comments (CID,Time,Name,Email,Comment) VALUES ($CID,$time," . $db->quote ($name) . "," . $db->quote ($email) . "," . $db->quote ($comment) . ")");
			$db->do ("DELETE FROM comments WHERE CID!=$CID AND Time>=" . ($time - 24 * 3600) . " AND Time<=" . ($time + 24 * 3600) . " AND Name=" . $db->quote ($name) . " AND Email=" . $db->quote ($email) . " AND Comment=" . $db->quote ($comment));
		}
		else
		{
			$CID = $db->selectrow_array ("SELECT CID FROM comments WHERE Time>=" . ($time - 24 * 3600) . " AND Time<=" . ($time + 24 * 3600) . " AND Name=" . $db->quote ($name) . " AND Email=" . $db->quote ($email) . " AND Comment=" . $db->quote ($comment));
			if ($CID)
			{
				$db->do ("UPDATE comments SET Time=$time WHERE CID=$CID");
			}
			else
			{
				$db->do ("INSERT INTO comments (Time,Name,Email,Comment) VALUES ($time," . $db->quote ($name) . "," . $db->quote ($email) . "," . $db->quote ($comment) . ")");
			}
		}
		$db->do ("UNLOCK TABLES");
	}
}

&db_disconnect ($db);

sub help
{
	print "Fast File Search import_comments.pl - Import comments\n";
	print "Usage: import_comments.pl [OPTION]... [FILE]...\n\n";
	print "    -m, --merge              Merge the database with FILEs (default)\n";
	print "    -o, --overwrite          Overwrite the records with the same ID\n";
	print "    -c, --common, --master   Use common (master) database (default)\n";
	print "    -p, --private, --slave   Use private (slave) database\n";
	print "    -h, --help               Display this help and exit\n\n";
}
