#!/usr/bin/perl

# Import FTP list from FemFind
# Copyright (c) 2002-2003 Josef Zlomek
#
# This file is part of Fast File Search (FFS).
#
# FFS is free software; you can redistribute it and/or modify it
# under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2, or (at your option)
# any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA,
# or download it from http://www.gnu.org/licenses/gpl.html

use strict;
use DBI;
use Getopt::Long;

# include the common package
$_ = $0;
$_ =~ s/[^\/]*$/common.pl/;
require;

my %c;
my $db;

my ($help, $private);
Getopt::Long::Configure ("bundling", "no_ignore_case");
GetOptions ('help|h' => \$help,
		'common|master|c' => sub { $private = 0 },
		'private|slave|p' => \$private,
		);
if ($help)
{
	&help ();
	exit 0;
}

&read_config (\%c);
if ($private)
{
	&db_connect (\%c, undef, \$db);
}
else
{
	&db_connect (\%c, \$db);
}
exit 1 if (!$db);

while (<>)
{
	chomp;
	last if (/^\r?$/);
	if (/^(.*?)#__(.*?)#__(.*?)#__(\d*?)#__(.*)$/)
	{
		my $hostname = $1;
		next if (!$hostname);
		my $login = $2;
		$login = 'anonymous' if (!$login);
		my $password = $3;
		$password = 'user@host.com' if (!$password);
		my $port = $4;
		$port = 21 if (!$port);
		my $comment = $5;

		$db->do ("LOCK TABLES host WRITE, ftp WRITE");
		my ($HID, $flags) = $db->selectrow_array ("SELECT host.HID,Flags FROM ftp LEFT JOIN host USING (HID) WHERE HostName=" . $db->quote ($hostname) . " AND Login=" . $db->quote ($login) . " AND PassWord=" . $db->quote ($password) . " AND Port=$port AND StartingDir=''");
		if ($HID)
		{
			my $clear_flags = $c{HOST_DELETE} | $c{HOST_PURGE};
			my $str;
			$str = "ExpireCount=1,Counter=Period," if ($flags & ($c{HOST_DELETE} | $c{HOST_PURGE}));
			$db->do ("UPDATE host SET ${str}Flags=Flags&~$clear_flags WHERE HID=$HID");
			$db->do ("UPDATE ftp SET Comment=" . $db->quote ($comment) . " WHERE HID=$HID");
		}
		else
		{
			$db->do ("INSERT INTO host (HostType,ExpireCount,Period,Counter) VALUES ($c{FTP},1,1,1)");
			$db->do ("INSERT INTO ftp (HID,HostName,Login,PassWord,Port,Comment) VALUES (LAST_INSERT_ID()," . $db->quote ($hostname) . "," . $db->quote ($login) . "," . $db->quote ($password) . ",$port," . $db->quote ($comment) . ")");
		}
		$db->do ("UNLOCK TABLES");
	}
}

&db_disconnect ($db);

sub help
{
	print "Fast File Search import_femfind_ftp_list.pl - Import FemFind's FTP list\n";
	print "Usage: import_femfind_ftp_list.pl [OPTION]... [FILE]...\n\n";
	print "    -c, --common, --master   Use common (master) database (default)\n";
	print "    -p, --private, --slave   Use private (slave) database\n";
	print "    -h, --help               Display this help and exit\n\n";
}
