#!/usr/bin/perl

# Import host list
# Copyright (c) 2002-2003 Josef Zlomek
#
# This file is part of Fast File Search (FFS).
#
# FFS is free software; you can redistribute it and/or modify it
# under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2, or (at your option)
# any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA,
# or download it from http://www.gnu.org/licenses/gpl.html

use strict;
use DBI;
use Getopt::Long;

# include the common package
$_ = $0;
$_ =~ s/[^\/]*$/common.pl/;
require;
use vars qw($import_num $import_nnum $import_str0 $import_str1);

my ($help, $private, $overwrite);
Getopt::Long::Configure ("bundling", "no_ignore_case");
GetOptions ('help|h' => \$help,
		'merge|m' => sub { $overwrite = 0 },
		'overwrite|o' => \$overwrite,
		'common|master|c' => sub { $private = 0 },
		'private|slave|p' => \$private,
		);
if ($help)
{
	&help ();
	exit 0;
}

my %c;
my $db;

&read_config (\%c);
if ($private)
{
	&db_connect (\%c, undef, \$db);
}
else
{
	&db_connect (\%c, \$db);
}
exit 1 if (!$db);

while (<>)
{
	chomp;
	last if (/^\r?$/);
	if (/^$import_num,$import_num,$import_nnum,$import_num,$import_str1,$import_str0,$import_str0,$import_num,$import_str0,$import_str0,$import_str0,$import_str0,$import_str0$/)
	{
		my $HID = $1;
		my $period = $2;
		my $scanorder = $3;
		my $flags = $4;
		my $hostname = &unquote ($5);
		my $login = &unquote ($6);
		my $password = &unquote ($7);
		my $port = $8;
		my $editableby = &unquote ($9);
		my $comment = &unquote ($10);
		my $starting_dir = &unquote ($11);
		my $ip = &unquote ($12);
		$ip = '' if (&is_invalid_IP ($ip));
		my $filelist = &unquote ($13);

		if ($overwrite)
		{
			$db->do ("LOCK TABLES host WRITE, ftp WRITE, smb WRITE");
			$db->do ("DELETE FROM smb WHERE HID=$HID");
			$db->do ("DELETE FROM ftp WHERE HID=$HID");
			$db->do ("REPLACE INTO host (HID,IP,HostType,ExpireCount,Period,Counter,ScanOrder,Flags) VALUES ($HID," . $db->quote ($ip) . ",$c{FTP},1,$period,$period,$scanorder,$flags)");
			$db->do ("INSERT INTO ftp (HID,HostName,Login,PassWord,Port,StartingDir,FileList,Comment,EditableBy) VALUES ($HID," . $db->quote ($hostname) . "," . $db->quote ($login) . "," . $db->quote ($password) . ",$port," . $db->quote ($starting_dir) . "," . $db->quote ($filelist) . "," . $db->quote ($comment) . "," . $db->quote ($editableby) . ")");
		}
		else
		{
			$db->do ("LOCK TABLES host WRITE, ftp WRITE");
			my ($resHID, $resflags) = $db->selectrow_array ("SELECT host.HID,Flags FROM ftp LEFT JOIN host USING (HID) WHERE HostName=" . $db->quote ($hostname) . " AND Login=" . $db->quote ($login) . " AND PassWord=" . $db->quote ($password) . " AND Port=$port AND StartingDir=" . $db->quote ($starting_dir));
			if ($resHID)
			{
				my $str;
				$str = "ExpireCount=1,Counter=$period," if ($resflags & ($c{HOST_DELETE} | $c{HOST_PURGE}));
				$db->do ("UPDATE host SET ${str}IP=" . $db->quote ($ip) . ",Period=$period,ScanOrder=$scanorder,Flags=$flags WHERE HID=$resHID");
				$db->do ("UPDATE ftp SET FileList=" . $db->quote ($filelist) . ",Comment=" . $db->quote ($comment) . ",EditableBy=" . $db->quote ($editableby) . " WHERE HID=$resHID");
			}
			else
			{
				$db->do ("INSERT INTO host (IP,HostType,ExpireCount,Period,Counter,ScanOrder,Flags) VALUES (" . $db->quote ($ip) . ",$c{FTP},1,$period,$period,$scanorder,$flags)");
				$db->do ("INSERT INTO ftp (HID,HostName,Login,PassWord,Port,StartingDir,FileList,Comment,EditableBy) VALUES (LAST_INSERT_ID()," . $db->quote ($hostname) . "," . $db->quote ($login) . "," . $db->quote ($password) . ",$port," . $db->quote ($starting_dir) . "," . $db->quote ($filelist) . "," . $db->quote ($comment) . "," . $db->quote ($editableby) . ")");
			}
		}
		$db->do ("UNLOCK TABLES");
	}
}

while (<>)
{
	chomp;
	last if (/^\r?$/);
	if (/^$import_num,$import_num,$import_nnum,$import_num,$import_str1,$import_str0,$import_str0$/)
	{
		my $HID = $1;
		my $period = $2;
		my $scanorder = $3;
		my $flags = $4;
		my $hostname = &unquote ($5);
		my $workgroup = &unquote ($6);
		my $ip = &unquote ($7);
		$ip = '' if (&is_invalid_IP ($ip));

		if ($overwrite)
		{
			$db->do ("LOCK TABLES host WRITE, ftp WRITE, smb WRITE");
			$db->do ("DELETE FROM smb WHERE HID=$HID");
			$db->do ("DELETE FROM ftp WHERE HID=$HID");
			$db->do ("REPLACE INTO host (HID,IP,HostType,ExpireCount,Period,Counter,ScanOrder,Flags) VALUES ($HID," . $db->quote ($ip) . ",$c{SMB},1,$period,$period,$scanorder,$flags)");
			$db->do ("INSERT INTO smb (HID,HostName,WorkGroup) VALUES ($HID," . $db->quote ($hostname) . "," . $db->quote ($workgroup) . ")");
		}
		else
		{
			$db->do ("LOCK TABLES host WRITE, smb WRITE");
			my ($resHID, $resflags) = $db->selectrow_array ("SELECT host.HID,Flags FROM smb LEFT JOIN host USING (HID) WHERE HostName=" . $db->quote ($hostname));
			if ($resHID)
			{
				my $str;
				$str = "ExpireCount=1,Counter=$period," if ($resflags & ($c{HOST_DELETE} | $c{HOST_PURGE}));
				$db->do ("UPDATE host SET ${str}IP=" . $db->quote ($ip) . ",Period=$period,ScanOrder=$scanorder,Flags=$flags WHERE HID=$resHID");
				$db->do ("UPDATE smb SET WorkGroup=" . $db->quote ($workgroup) . " WHERE HID=$resHID");
			}
			else
			{
				$db->do ("INSERT INTO host (IP,HostType,ExpireCount,Period,Counter,ScanOrder,Flags) VALUES (" . $db->quote ($ip) . ",$c{SMB},1,$period,$period,$scanorder,$flags)");
				$db->do ("INSERT INTO smb (HID,HostName,WorkGroup) VALUES (LAST_INSERT_ID()," . $db->quote ($hostname) . "," . $db->quote ($workgroup) . ")");
			}
		}
		$db->do ("UNLOCK TABLES");
	}
}

&db_disconnect ($db);

sub help
{
	print "Fast File Search import_host_list.pl - Import host list\n";
	print "Usage: import_host_list.pl [OPTION]... [FILE]...\n\n";
	print "    -m, --merge              Merge the database with FILEs (default)\n";
	print "    -o, --overwrite          Overwrite the records with the same ID\n";
	print "    -c, --common, --master   Use common (master) database (default)\n";
	print "    -p, --private, --slave   Use private (slave) database\n";
	print "    -h, --help               Display this help and exit\n\n";
}
