#!/usr/bin/perl

# Create the necessary database settings.
# Copyright (c) 2002-2003 Josef Zlomek
#
# This file is part of Fast File Search (FFS).
#
# FFS is free software; you can redistribute it and/or modify it
# under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2, or (at your option)
# any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA,
# or download it from http://www.gnu.org/licenses/gpl.html

use strict;
use DBI;

# include the common package
$_ = $0;
$_ =~ s/[^\/]*$/bin\/common.pl/;
require;

my %c;
&read_config (\%c);

if ($c{DB_LOGIN} =~ /\s*root\s*$/i)
{
	print "\nIt is really BAD idea to use root MySQL account for Fast File Search.\nChange db_login to something else in ffsearch.conf\n\n";
	exit 1;
}

if ($c{MDB_LOGIN} =~ /\s*root\s*$/i)
{
	print "\nIt is really BAD idea to use root MySQL account for Fast File Search.\nChange mdb_login to something else in ffsearch.conf\n\n";
	exit 1;
}

my $db;
my $answer;
my $host;
my $rights;
my $delete_tables;

my @master_tables = ("admin", "comments", "host", "ftp", "smb");

print "\nI'm going to create database '$c{DB_NAME}' on '$c{DB_HOST}:$c{DB_PORT}'.\n",
	 "For different parameters, edit $c{CONFIG_FILE} (section Database) and rerun.\n\n";

&connect_to_db ($c{DB_HOST}, $c{DB_PORT});
&create_db ($c{DB_NAME});

my $is_master = 0;
$host = ($c{DB_HOST} eq 'localhost' || $c{DB_HOST} eq '127.0.0.1') ? 'localhost' : '%';
if ($host eq 'localhost')
{
	if ($c{MDB} ne $c{DB} || $c{MDB_LOGIN} ne $c{DB_LOGIN})
	{
		while (($answer = &ask ("May other FFS hosts use this database as master database (y/n) [N]?", "n")) !~ /^[YyNn]$/) {}
	}
	else
	{
		while (($answer = &ask ("May other FFS hosts use this database as master database (y/n) [Y]?", "y")) !~ /^[YyNn]$/) {}
	}
	$is_master = 1 if ($answer =~ /^[Yy]$/);
}

# create account(s)
print "Writing account info...\n";
&delete_privileges ($c{DB_NAME}, $c{DB_LOGIN});
&insert_user_privileges ($host, $c{DB_LOGIN}, $c{DB_PASSWORD});
&insert_db_privileges ($host, $c{DB_NAME}, $c{DB_LOGIN}, 1);
if ($is_master)
{
	&insert_user_privileges ('%', $c{DB_LOGIN}, $c{DB_PASSWORD});
	&insert_db_privileges ('%', $c{DB_NAME}, $c{DB_LOGIN}, 0);
	foreach (@master_tables)
	{
		&insert_table_privileges ('%', $c{DB_NAME}, $c{DB_LOGIN}, $_);
	}
}
$db->do ("FLUSH PRIVILEGES");
&rebuild_tables ($c{DB_NAME}, $c{DB}, $c{DB_LOGIN}, $c{DB_PASSWORD}, "--private");
$db->disconnect ();

#################### Master (common) database ########################
if ($c{MDB} ne $c{DB} || $c{MDB_LOGIN} ne $c{DB_LOGIN})
{
	$host = ($c{MDB_HOST} eq 'localhost' || $c{MDB_HOST} eq '127.0.0.1') ? 'localhost' : '%';
	if ($host ne 'localhost')
	{
		while (($answer = &ask ("Do you want to create master database '$c{MDB_NAME}' on '$c{MDB_HOST}:$c{MDB_PORT}' (y/n) [N]?", "n")) !~ /^[YyNn]$/) {}
	}
	else
	{
		while (($answer = &ask ("Do you want to create master database '$c{MDB_NAME}' on '$c{MDB_HOST}:$c{MDB_PORT}' (y/n) [Y]?", "y")) !~ /^[YyNn]$/) {}
	}
	if ($answer =~ /^[Yy]$/)
	{
		&connect_to_db ($c{MDB_HOST}, $c{MDB_PORT});
		&create_db ($c{MDB_NAME});

		print "Writing account info...\n";
		&delete_privileges ($c{MDB_NAME}, $c{MDB_LOGIN});
		&insert_user_privileges ($host, $c{MDB_LOGIN}, $c{MDB_PASSWORD});
		&insert_db_privileges ($host, $c{MDB_NAME}, $c{MDB_LOGIN}, 0);
		foreach (@master_tables)
		{
			&insert_table_privileges ($host, $c{MDB_NAME}, $c{MDB_LOGIN}, $_);
		}
		if ($host eq 'localhost')
		{
			&insert_user_privileges ('%', $c{MDB_LOGIN}, $c{MDB_PASSWORD});
			&insert_db_privileges ('%', $c{MDB_NAME}, $c{MDB_LOGIN}, 0);
			foreach (@master_tables)
			{
				&insert_table_privileges ('%', $c{MDB_NAME}, $c{MDB_LOGIN}, $_);
			}
		}

		$db->do ("FLUSH PRIVILEGES");
		&rebuild_tables ($c{MDB_NAME}, $c{MDB}, $c{MDB_LOGIN}, $c{MDB_PASSWORD}, "--common");
		$db->disconnect ();
	}
}

print "\nInstallation completed.\n";
exit 0;

######################## Subroutines #######################

sub connect_to_db
{
	my ($host, $port) = @_;
	my ($mysql_user, $mysql_password);

	$mysql_user = &ask ("MySQL user (must be able to access the 'mysql' database) [root]: ", "root");
	&echo_off ();
	$mysql_password = &ask ("Password: ", "");
	print "\n";
	&echo_on ();

	$db = DBI->connect ("DBI:mysql:mysql;host=$host;port=$port", $mysql_user, $mysql_password, {PrintError => 0})
		|| die "Could not connect to database, reason: $DBI::errstr\n";
}

sub create_db
{
	my ($name) = @_;

	$delete_tables = 0;
	my $dbs = $db->selectcol_arrayref ("SHOW DATABASES");
	foreach (@$dbs)
	{
		if ($_ eq $name)
		{
			$delete_tables = 1;
			print "Database '$name' already exists.\n";
			while (($answer = &ask ("Delete all tables and rebuild them? (y/n) [Y]: ", "y")) !~ /^[YyNn]$/) {}
			if ($answer =~ /^[Nn]$/)
			{
				$delete_tables = 2;
			}
			last;
		}
	}

	if ($delete_tables == 0)
	{
		$db->do ("CREATE DATABASE $name")
			|| die "Could not create database '$name' - reason: $DBI::errstr\n";
	}
}

sub delete_privileges
{
	my ($name, $login) = @_;

	$db->do ("DELETE FROM user WHERE User=" . $db->quote ($login) . " AND (Host='localhost' OR Host='%')");
	$db->do ("DELETE FROM db WHERE User=" . $db->quote ($login) . " AND (Host='localhost' OR Host='%') AND Db=" . $db->quote ($name));
	$db->do ("DELETE FROM tables_priv WHERE User=" . $db->quote ($login) . " AND (Host='localhost' OR Host='%') AND Db=" . $db->quote ($name));
}

sub insert_user_privileges
{
	my ($host, $user, $password) = @_;

	$db->do ("INSERT INTO user (Host,User,Password) VALUES "
		. "(" . $db->quote ($host) . "," . $db->quote ($user)
		. ",PASSWORD(" . $db->quote ($password) . "))")
	|| print "Error while inserting, reason: $DBI::errstr\n";
}

sub insert_db_privileges
{
	my ($host, $db_name, $user, $allow) = @_;

	if ($allow)
	{
		$db->do ("INSERT INTO db (Host,Db,User,Select_priv,Insert_priv,Update_priv,Delete_priv,Create_priv,Drop_priv,Index_priv,Alter_priv) VALUES "
				. "(" . $db->quote ($host) . "," . $db->quote ($db_name) . ","
				. $db->quote ($user) . ",'Y'" x 8 . ")")
			|| print "Error while inserting, reason: $DBI::errstr\n";

		# MySQL 4 needs one more privilege
		$db->do ("UPDATE db SET Lock_tables_priv='Y' WHERE "
				. "Host=" . $db->quote ($host)
				. " AND Db=" . $db->quote ($db_name)
				. " AND User=" . $db->quote ($user));
	}
	else
	{
		$db->do ("INSERT INTO db (Host,Db,User) VALUES "
				. "(" . $db->quote ($host) . "," . $db->quote ($db_name) . ","
				. $db->quote ($user) . ")")
			|| print "Error while inserting, reason: $DBI::errstr\n";
	}
}

sub insert_table_privileges
{
	my ($host, $db_name, $user, $table) = @_;

	$db->do ("INSERT INTO tables_priv (Host,Db,User,Table_name,Table_priv) VALUES "
			. "(" . $db->quote ($host) . "," . $db->quote ($db_name) . ","
			. $db->quote ($user) . "," . $db->quote ($table)
			. ",'Select,Insert,Delete,Update')")
		|| print "Error while inserting, reason: $DBI::errstr\n";
}

sub rebuild_tables
{
	my ($name, $db_str, $login, $password, $which_db) = @_;
	if ($delete_tables != 2)
	{
		# export data
		if ($delete_tables == 1)
		{
			print "Saving host list...\n";
			system ("./bin/export_host_list.pl $which_db > hostlist");
			print "Saving admins...\n";
			system ("./bin/export_admins.pl $which_db > admins");
			print "Saving comments...\n";
			system ("./bin/export_comments.pl $which_db > comments");
		}

		print "Creating tables...\n";
		$db->do ("USE $name")
			|| die "Could not select database, reason: $DBI::errstr\n";
		&create_tables ($db);

		# import data
		if ($delete_tables == 1)
		{
			print "Restoring host list...\n";
			system ("./bin/import_host_list.pl $which_db --overwrite < hostlist");
			unlink ("hostlist");
			print "Restoring admins...\n";
			system ("./bin/import_admins.pl $which_db --overwrite < admins");
			unlink ("admins");
			print "Restoring comments...\n";
			system ("./bin/import_comments.pl $which_db --overwrite < comments");
			unlink ("comments");
		}
	}
}
